@@ -5,17 +5,11 @@ import pandas as pd
 import datetime 
 from tqdm import tqdm 
 
-# +
 import torch
 from torch import nn 
 from accelerate import Accelerator
 from copy import deepcopy
 
-__version__ = '3.0.1'
-
-
-# -
-
 def printlog(info):
     nowtime = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
     print("\n"+"=========="*8 + "%s"%nowtime)
@@ -61,10 +55,12 @@ class EpochRunner:
     def __call__(self,dataloader):
         total_loss,step = 0,0
         loop = tqdm(enumerate(dataloader), total =len(dataloader))
-        for i, batch in loop:
-            features,labels = batch
-            loss, step_metrics = self.steprunner(features,labels)
-
+        for i, batch in loop: 
+            if self.stage=="train":
+                loss, step_metrics = self.steprunner(*batch)
+            else:
+                with torch.no_grad():
+                    loss, step_metrics = self.steprunner(*batch)
             step_log = dict({self.stage+"_loss":loss},**step_metrics)
 
             total_loss += loss
@@ -167,6 +163,7 @@ class KerasModel(torch.nn.Module):
     @torch.no_grad()
     def predict(self, dataloader):
         dataloader = self.accelerator.prepare(dataloader)
+        self.net.eval()
         result = torch.cat([self.forward(t[0]) for t in dataloader])
         return result.data
 
